aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael Paquier <michael@paquier.xyz>2022-11-25 16:37:49 +0900
committerMichael Paquier <michael@paquier.xyz>2022-11-25 16:37:49 +0900
commit9e492d6b693a60d53a5d3d8fbd40ae253b7d22f5 (patch)
tree4b5efc28bf700e525e306f0544214747bf1fc586
parentd13b684117bdf136f97db5bcba2be524ed038b6d (diff)
downloadpostgresql-9e492d6b693a60d53a5d3d8fbd40ae253b7d22f5.tar.gz
postgresql-9e492d6b693a60d53a5d3d8fbd40ae253b7d22f5.zip
Skip TAP test for peer authentication if there are no unix-domain sockets
Peer connections require support for local connections to work, but the test missed the same check as the other ones in this suite. The buildfarm does not run the authentication tests on Windows, and, more surprisingly, the CI with meson was already able to skip it. Author: Anton A. Melnikov Discussion: https://postgr.es/m/28b9d685-9590-45b1-fe87-358d61c6950a@inbox.ru
-rw-r--r--src/test/authentication/t/003_peer.pl8
1 files changed, 7 insertions, 1 deletions
diff --git a/src/test/authentication/t/003_peer.pl b/src/test/authentication/t/003_peer.pl
index ce8408a4f8c..26c34d05d3c 100644
--- a/src/test/authentication/t/003_peer.pl
+++ b/src/test/authentication/t/003_peer.pl
@@ -2,13 +2,19 @@
# Copyright (c) 2021-2022, PostgreSQL Global Development Group
# Tests for peer authentication and user name map.
# The test is skipped if the platform does not support peer authentication.
use strict;
use warnings;
use PostgreSQL::Test::Cluster;
use PostgreSQL::Test::Utils;
use Test::More;
+if (!$use_unix_sockets)
+{
+ plan skip_all =>
+ "authentication tests cannot run without Unix-domain sockets";
+}
# Delete pg_hba.conf from the given node, add a new entry to it
# and then execute a reload to refresh it.
@@ -2,13 +2,19 @@
# Copyright (c) 2021-2022, PostgreSQL Global Development Group
# Tests for peer authentication and user name map.
-# The test is skipped if the platform does not support peer authentication.
+# The test is skipped if the platform does not support peer authentication,
+# and is only able to run with Unix-domain sockets.
use strict;
use warnings;